==> haskell-tasty-kat-0.0.3-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-7uDhbA80fKjJzPx69wo8YE
key:                  tasty-kat-0.0.3-7uDhbA80fKjJzPx69wo8YE
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  e05a55053c575cb2fea98812547c5327
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-kat-0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-7uDhbA80fKjJzPx69wo8YE
depends:
    base-4.17.2.1 bytestring-0.11.5.3 tasty-1.5-2drm3vbeJH2JfJ6SzRblHQ

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-kat-0.0.3-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-LWnlo5rJqFa9itVs7K1ELK
key:                  tasty-kat-0.0.3-LWnlo5rJqFa9itVs7K1ELK
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  6b920836fed30948f49edce81a1cbb08
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-kat-0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-LWnlo5rJqFa9itVs7K1ELK
depends:
    base-4.17.2.1 bytestring-0.11.5.3 tasty-1.5-HBdWNiCF1HoGs6Y5nYbVGN

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
